@@ -1,5 +1,7 @@
 from __future__ import absolute_import, unicode_literals
 
+import django
+
 __all__ = ['VERSION']
 
 
@@ -11,9 +13,10 @@ except Exception:
 
 
 # Code that discovers files or modules in INSTALLED_APPS imports this module.
-# Reference URLpatterns with a string to avoid the risk of circular imports.
-
-urls = 'debug_toolbar.toolbar', 'djdt', 'djdt'
 
+if django.VERSION < (1, 9):
+    urls = 'debug_toolbar.toolbar', 'djdt', 'djdt'
+else:
+    urls = 'debug_toolbar.toolbar', 'djdt'
 
 default_app_config = 'debug_toolbar.apps.DebugToolbarConfig'
