@@ -1,6 +1,6 @@
 from __future__ import absolute_import, unicode_literals
 
-from django.shortcuts import render_to_response
+from django.template.response import SimpleTemplateResponse
 from django.utils.translation import ugettext_lazy as _
 
 from debug_toolbar.panels import Panel
@@ -22,6 +22,8 @@ class RedirectsPanel(Panel):
                 status_line = '%s %s' % (response.status_code, response.reason_phrase)
                 cookies = response.cookies
                 context = {'redirect_to': redirect_to, 'status_line': status_line}
-                response = render_to_response('debug_toolbar/redirect.html', context)
+                # Using SimpleTemplateResponse avoids running global context processors.
+                response = SimpleTemplateResponse('debug_toolbar/redirect.html', context)
                 response.cookies = cookies
+                response.render()
         return response
