@@ -38,8 +38,14 @@ def wrap_cursor(connection, panel):
     if not hasattr(connection, '_djdt_cursor'):
         connection._djdt_cursor = connection.cursor
 
-        def cursor():
-            return state.Wrapper(connection._djdt_cursor(), connection, panel)
+        def cursor(*args, **kwargs):
+            # Per the DB API cursor() does not accept any arguments. There's
+            # some code in the wild which does not follow that convention,
+            # so we pass on the arguments even though it's not clean.
+            # See:
+            # https://github.com/jazzband/django-debug-toolbar/pull/615
+            # https://github.com/jazzband/django-debug-toolbar/pull/896
+            return state.Wrapper(connection._djdt_cursor(*args, **kwargs), connection, panel)
 
         connection.cursor = cursor
         return cursor
@@ -85,9 +91,8 @@ class NormalCursorWrapper(object):
         if not params:
             return params
         if isinstance(params, dict):
-            return dict((key, self._quote_expr(value))
-                        for key, value in params.items())
-        return list(map(self._quote_expr, params))
+            return {key: self._quote_expr(value) for key, value in params.items()}
+        return [self._quote_expr(p) for p in params]
 
     def _decode(self, param):
         try:
@@ -108,7 +113,7 @@ class NormalCursorWrapper(object):
                 stacktrace = []
             _params = ''
             try:
-                _params = json.dumps(list(map(self._decode, params)))
+                _params = json.dumps([self._decode(p) for p in params])
             except Exception:
                 pass  # object not JSON serializable
 
