@@ -9,7 +9,7 @@ from sqlparse import tokens as T
 
 class BoldKeywordFilter:
     """sqlparse filter to bold SQL keywords"""
-    def process(self, stack, stream):
+    def process(self, stream):
         """Process the token stream"""
         for token_type, value in stream:
             is_keyword = token_type in T.Keyword
