@@ -4,9 +4,11 @@ from django.http import HttpResponse
 from django.utils.html import escape
 from django.utils.translation import ugettext as _
 
+from debug_toolbar.decorators import require_show_toolbar
 from debug_toolbar.toolbar import DebugToolbar
 
 
+@require_show_toolbar
 def render_panel(request):
     """Render the contents of a panel"""
     toolbar = DebugToolbar.fetch(request.GET['store_id'])
