@@ -4,12 +4,10 @@ import copy
 
 from django.conf import settings
 from django.http import HttpResponse
-from django.test.utils import override_settings
 
 from ..base import BaseTestCase
 
 
-@override_settings(DEBUG_TOOLBAR_CONFIG={'INTERCEPT_REDIRECTS': True})
 class RedirectsPanelTestCase(BaseTestCase):
 
     def setUp(self):
@@ -38,7 +36,7 @@ class RedirectsPanelTestCase(BaseTestCase):
 
     def test_redirect_with_broken_context_processor(self):
         TEMPLATES = copy.deepcopy(settings.TEMPLATES)
-        TEMPLATES[0]['OPTIONS']['context_processors'] = ['tests.context_processors.broken']
+        TEMPLATES[1]['OPTIONS']['context_processors'] = ['tests.context_processors.broken']
 
         with self.settings(TEMPLATES=TEMPLATES):
             redirect = HttpResponse(status=302)
