@@ -26,7 +26,7 @@ class SQLPanelTestCase(BaseTestCase):
 
     def test_disabled(self):
         config = {
-            'DISABLE_PANELS': set(['debug_toolbar.panels.sql.SQLPanel'])
+            'DISABLE_PANELS': {'debug_toolbar.panels.sql.SQLPanel'}
         }
         self.assertTrue(self.panel.enabled)
         with self.settings(DEBUG_TOOLBAR_CONFIG=config):
@@ -81,6 +81,7 @@ class SQLPanelTestCase(BaseTestCase):
         self.panel.generate_stats(self.request, self.response)
         # ensure the panel renders correctly.
         self.assertIn('café', self.panel.content)
+        self.assertValidHTML(self.panel.content)
 
     @unittest.skipUnless(connection.vendor == 'postgresql',
                          'Test valid only on PostgreSQL')
