@@ -4,6 +4,7 @@ from __future__ import absolute_import, unicode_literals
 
 from django.contrib.auth.models import User
 from django.template import Context, RequestContext, Template
+from django.test import TestCase, override_settings
 
 from ..base import BaseTestCase
 from ..models import NonAsciiRepr
@@ -63,6 +64,7 @@ class TemplatesPanelTestCase(BaseTestCase):
         self.panel.generate_stats(self.request, self.response)
         # ensure the panel renders correctly.
         self.assertIn('nôt åscíì', self.panel.content)
+        self.assertValidHTML(self.panel.content)
 
     def test_custom_context_processor(self):
         self.panel.process_request(self.request)
@@ -75,13 +77,22 @@ class TemplatesPanelTestCase(BaseTestCase):
 
     def test_disabled(self):
         config = {
-            'DISABLE_PANELS': set([
-                'debug_toolbar.panels.templates.TemplatesPanel'])
+            'DISABLE_PANELS': {'debug_toolbar.panels.templates.TemplatesPanel'}
         }
         self.assertTrue(self.panel.enabled)
         with self.settings(DEBUG_TOOLBAR_CONFIG=config):
             self.assertFalse(self.panel.enabled)
 
 
+@override_settings(DEBUG=True,
+                   DEBUG_TOOLBAR_PANELS=['debug_toolbar.panels.templates.TemplatesPanel'])
+class JinjaTemplateTestCase(TestCase):
+    def test_django_jinja2(self):
+        r = self.client.get('/regular_jinja/foobar/')
+        self.assertContains(r, 'Test for foobar (Jinja)')
+        self.assertContains(r, '<h3>Templates (1 rendered)</h3>')
+        self.assertContains(r, '<small>jinja2/basic.jinja</small>')
+
+
 def context_processor(request):
     return {'content': 'set by processor'}
