@@ -8,11 +8,14 @@ from xml.etree import ElementTree as ET
 
 import django
 from django.contrib.staticfiles.testing import StaticLiveServerTestCase
+from django.core import signing
 from django.core.checks import Error, run_checks
+from django.template.loader import get_template
 from django.test import RequestFactory, TestCase
 from django.test.utils import override_settings
 
 from debug_toolbar.middleware import DebugToolbarMiddleware, show_toolbar
+from debug_toolbar.toolbar import DebugToolbar
 
 from .base import BaseTestCase
 from .views import regular_view
@@ -120,6 +123,121 @@ class DebugToolbarIntegrationTestCase(TestCase):
         response = self.client.get('/regular/XML/')
         ET.fromstring(response.content)     # shouldn't raise ParseError
 
+    def test_render_panel_checks_show_toolbar(self):
+        toolbar = DebugToolbar(None)
+        toolbar.store()
+        url = '/__debug__/render_panel/'
+        data = {'store_id': toolbar.store_id, 'panel_id': 'VersionsPanel'}
+
+        response = self.client.get(url, data)
+        self.assertEqual(response.status_code, 200)
+        response = self.client.get(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+        self.assertEqual(response.status_code, 200)
+        with self.settings(INTERNAL_IPS=[]):
+            response = self.client.get(url, data)
+            self.assertEqual(response.status_code, 404)
+            response = self.client.get(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+            self.assertEqual(response.status_code, 404)
+
+    def test_template_source_checks_show_toolbar(self):
+        template = get_template('basic.html')
+        url = '/__debug__/template_source/'
+        data = {
+            'template': template.template.name,
+            'template_origin': signing.dumps(template.template.origin.name)
+        }
+
+        response = self.client.get(url, data)
+        self.assertEqual(response.status_code, 200)
+        response = self.client.get(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+        self.assertEqual(response.status_code, 200)
+        with self.settings(INTERNAL_IPS=[]):
+            response = self.client.get(url, data)
+            self.assertEqual(response.status_code, 404)
+            response = self.client.get(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+            self.assertEqual(response.status_code, 404)
+
+    def test_sql_select_checks_show_toolbar(self):
+        url = '/__debug__/sql_select/'
+        data = {
+            'sql': 'SELECT * FROM auth_user',
+            'raw_sql': 'SELECT * FROM auth_user',
+            'params': '{}',
+            'alias': 'default',
+            'duration': '0',
+            'hash': '6e12daa636b8c9a8be993307135458f90a877606',
+        }
+
+        response = self.client.post(url, data)
+        self.assertEqual(response.status_code, 200)
+        response = self.client.post(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+        self.assertEqual(response.status_code, 200)
+        with self.settings(INTERNAL_IPS=[]):
+            response = self.client.post(url, data)
+            self.assertEqual(response.status_code, 404)
+            response = self.client.post(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+            self.assertEqual(response.status_code, 404)
+
+    def test_sql_explain_checks_show_toolbar(self):
+        url = '/__debug__/sql_explain/'
+        data = {
+            'sql': 'SELECT * FROM auth_user',
+            'raw_sql': 'SELECT * FROM auth_user',
+            'params': '{}',
+            'alias': 'default',
+            'duration': '0',
+            'hash': '6e12daa636b8c9a8be993307135458f90a877606',
+        }
+
+        response = self.client.post(url, data)
+        self.assertEqual(response.status_code, 200)
+        response = self.client.post(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+        self.assertEqual(response.status_code, 200)
+        with self.settings(INTERNAL_IPS=[]):
+            response = self.client.post(url, data)
+            self.assertEqual(response.status_code, 404)
+            response = self.client.post(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+            self.assertEqual(response.status_code, 404)
+
+    def test_sql_profile_checks_show_toolbar(self):
+        url = '/__debug__/sql_profile/'
+        data = {
+            'sql': 'SELECT * FROM auth_user',
+            'raw_sql': 'SELECT * FROM auth_user',
+            'params': '{}',
+            'alias': 'default',
+            'duration': '0',
+            'hash': '6e12daa636b8c9a8be993307135458f90a877606',
+        }
+
+        response = self.client.post(url, data)
+        self.assertEqual(response.status_code, 200)
+        response = self.client.post(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+        self.assertEqual(response.status_code, 200)
+        with self.settings(INTERNAL_IPS=[]):
+            response = self.client.post(url, data)
+            self.assertEqual(response.status_code, 404)
+            response = self.client.post(url, data, HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+            self.assertEqual(response.status_code, 404)
+
+    @override_settings(DEBUG_TOOLBAR_CONFIG={'RENDER_PANELS': True})
+    def test_data_store_id_not_rendered_when_none(self):
+        url = '/regular/basic/'
+        response = self.client.get(url)
+        self.assertIn(b'id="djDebug"', response.content)
+        self.assertNotIn(b'data-store-id', response.content)
+
+    def test_view_returns_template_response(self):
+        response = self.client.get('/template_response/basic/')
+        self.assertEqual(response.status_code, 200)
+
+    @override_settings(DEBUG_TOOLBAR_CONFIG={'DISABLE_PANELS': set()})
+    def test_incercept_redirects(self):
+        response = self.client.get('/redirect/')
+        self.assertEqual(response.status_code, 200)
+        # Link to LOCATION header.
+        self.assertIn(b'href="/regular/redirect/"', response.content)
+
 
 @unittest.skipIf(webdriver is None, "selenium isn't installed")
 @unittest.skipUnless('DJANGO_SELENIUM_TESTS' in os.environ, "selenium tests not requested")
@@ -153,6 +271,20 @@ class DebugToolbarLiveTestCase(StaticLiveServerTestCase):
         self.assertIn("Name", table.text)
         self.assertIn("Version", table.text)
 
+    @override_settings(DEBUG_TOOLBAR_CONFIG={
+        'DISABLE_PANELS':
+            {'debug_toolbar.panels.redirects.RedirectsPanel'}
+    })
+    def test_basic_jinja(self):
+        self.selenium.get(self.live_server_url + '/regular_jinja/basic')
+        template_panel = self.selenium.find_element_by_id('TemplatesPanel')
+
+        # Click to show the template panel
+        self.selenium.find_element_by_class_name('TemplatesPanel').click()
+
+        self.assertIn('Templates (1 rendered)', template_panel.text)
+        self.assertIn('jinja2/basic.jinja', template_panel.text)
+
     @override_settings(DEBUG_TOOLBAR_CONFIG={'RESULTS_CACHE_SIZE': 0})
     def test_expired_store(self):
         self.selenium.get(self.live_server_url + '/regular/basic/')
@@ -255,7 +387,7 @@ class DebugToolbarSystemChecksTestCase(BaseTestCase):
     def test_middleware_factory_functions_supported(self):
         messages = run_checks()
 
-        if django.VERSION[:2] < (1, 10):
+        if django.VERSION[:2] < (1, 10) or django.VERSION[:2] >= (2, 0):
             self.assertEqual(messages, [])
         else:
             self.assertEqual(messages[0].id, '1_10.W001')
